<!DOCTYPE html>
<html>

<head>
    <meta charset="utf-8" />
    <title>Verify your ActivityPub Actor</title>
    <link rel="stylesheet" href="static/styles.css">
</head>

<body>
    <main>
        <h1>Verifying your Actor</h1>

        <form action="/" method="POST">
            <label for="actor_uri">Actor URI to verify</label>
            <input type="text" name="actor_uri" id="actor_uri" />
            <input type="submit" value="Verify" />
        </form>

        <p>Support actor URI formats are:
        <ul>
            <li>HTTP URI, e.g.
                <code>http://pasture_verify_actor/alice</code>
            </li>
            <li>Account URI using webfinger, e.g.
                <code>acct:alice@pasture_verify_actor</code>
            </li>
            <li>Fediverse type handle, e.g.
                <code>alice@pasture_verify_actor</code> or
                <code>@alice@pasture_verify_actor</code>
            </li>
        </ul>
        For more information see the <a
            href="https://helge.codeberg.page/funfedidev/fediverse_pasture/tools/verify_actor/">Documentation</a></p>
    </main>
</body>

</html>